@@ -117,7 +117,7 @@ $F->cls('OFF');
 $F->splash($VERSION);
 update();
 sleep 1;
-# $F->acceleration(0);
+
 # if (0) {
 color_mapping();
 plotting();
@@ -1052,7 +1052,10 @@ sub flood_fill {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
 
         #        $F->plot({x=>350*$xm,y=>250*$ym,pixel_size=>10});sleep 20;
-        $F->fill({ 'x' => 350 * $xm, 'y' => 250 * $ym, 'texture' => $image });
+        my $saved = $F->{'ACCELERATED'};
+        $F->{'ACCELERATED'} = 0;
+        $F->fill({ 'x' => int(350 * $xm), 'y' => int(250 * $ym), 'texture' => $image });
+        $F->{'ACCELERATED'} = $saved;
         $STAMP = '';update();
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
