@@ -50,7 +50,7 @@ sub _perl_logo {
         $self->ttf_print(
             {
                 'bounding_box' => TRUE,
-                'y'            => (126 * $vf) + $Y,                                     # 85 * $vf,
+                'y'            => (126 * $vf) + $Y,                              # 85 * $vf,
                 'height'       => 80 * $vf,
                 'wscale'       => 1,
                 'color'        => '0040FFFF',
@@ -76,8 +76,8 @@ sub splash {
 
     my $hf = $W / 1920;    # Scales the logo
     my $vf = $H / 1080;
-    $self->{'H_SCALE'} = $hf;
-    $self->{'V_SCALE'} = $vf;
+    $self->{'H_SCALE'}  = $hf;
+    $self->{'V_SCALE'}  = $vf;
     $self->{'H_OFFSET'} = $X;
     $self->{'V_OFFSET'} = $Y;
 
@@ -272,7 +272,7 @@ sub splash {
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
-                    'colors'     => {
+                    'colors'    => {
                         'red'   => [255, 64, 255],
                         'green' => [255, 64, 255],
                         'blue'  => [255, 64, 255],
@@ -566,7 +566,7 @@ sub splash {
         }
         $self->ttf_print($scaleit);
         $self->_perl_logo();
-    } ## end else [ if (1 && (($W <= 320) ...))]
+    } ## end else [ if ((($W <= 320) || ($H...)))]
     $self->normal_mode();
 } ## end sub splash
 
